Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewHandler ¶
func NewHandler(cs kubernetes.Interface) http.HandlerFunc
NewHandler is web handler to return history of workload updates as performed by cvmanager
func NewProvider ¶
func NewProvider(cs kubernetes.Interface, stats stats.Stats) *provider
Types ¶
type Provider ¶
type Provider interface {
// History returns the historical record in CV update history
History(namespace, name string) (string, error)
// Add adds the history record in CV update history
Add(namespace, name string, record *Record) error
}
Provider is an interface to add and fetch cv release/update history
Source Files
¶
- handler.go
- provider.go
Click to show internal directories.
Click to hide internal directories.